/** Normalized ICO Neuron.
 *  
 *        \filename  NeuronNICO.h
 *  
 *           \class  NeuronNICO
 *
 *                   A normalized ICO Neuron that inherit from Neuron
 *                   or ICO Neuron, respectively.\n
 *                   Learning rule:
 *                   \f[
 *                   \Delta \rho_i(t) = \mu \cdot N(u_i(t)) \cdot u_0^{'}(t) 
 *                   \f]
 *                   where \f$\mu\f$ is the learning rate \n
 *                   and \f$\rho_i\f$ is the weight \n
 *                   and \f$u_i\f$ with \f$i=1..n\f$ are the
 *                   predictive inputs \n
 *                   and \f$N()\f$ is a normalizing function \n
 *                   and \f$u_0\f$ is the reflex input.
 *                   \n
 *                   \b learning rate (default) = 1e-4
 *  
 *            \date  01/03/2007 08:28:12 PM CET
 *
 *         \version  1.0
 *          \author  Christoph Kolodziejski (kolo), kolo@bccn-goettingen.de
 *                   BCCN Goettingen
 *  
 */

#ifndef _NeuronNICO_h_
#define _NeuronNICO_h_

// =====================================================================================
// System Includes
// =====================================================================================

#include <iostream>

// =====================================================================================
// Project Includes
// =====================================================================================

#include "NeuronICO.h"

// =====================================================================================
// Forward class declarations
// =====================================================================================


// =====================================================================================
// =====================================================================================
class NeuronNICO : public NeuronICO
{

  public:

    // ====================  LIFECYCLE   ========================================= 

    /*! Constructor */
    NeuronNICO (){};

    NeuronNICO(double learningRate):NeuronICO(learningRate){};

    // ====================  OPERATORS   ========================================= 

    // ====================  OPERATIONS  ========================================= 

    /** Calculation of the next output.
     *
     *              Iterates all connected synapses and calculates the \b
     *              nextoutput_ according to the normalized ICO rule.
     *              
     *    @remarks  The flags are: \n
     *              \b 0 <=> Reflex input (will not be learned) \n
     *              \b 1 <=> Predictive input (will be learned) \n
     *              \b 2 <=> Normalized predictive input (will not be learned)
     */
    void calculate();

    // ====================  ACCESS      ========================================= 

    // ====================  INQUIRY     ========================================= 

  protected:

  private:

};

#endif
